@@ -1,12 +1,12 @@
 import re
-from syncloud.tools.logger import get_logger
+from syncloud.app import logger
 
 
 class CpuInfo:
 
     def __init__(self, reader):
         self.reader = reader
-        self.logger = get_logger('CpuInfo')
+        self.logger = logger.get_logger('CpuInfo')
 
     def hardware(self):
         return self.value('hardware')
