@@ -1,11 +1,11 @@
-from syncloud.tools.logger import get_logger
+from syncloud.app import logger
 
 
 class Reader:
 
     def __init__(self, proc_cpuinfo='/proc/cpuinfo'):
         self.proc_cpuinfo = proc_cpuinfo
-        self.logger = get_logger('Reader')
+        self.logger = logger.get_logger('Reader')
         
     def read(self):
         self.logger.info('reading {}'.format(self.proc_cpuinfo))
